@@ -115,7 +115,9 @@ namespace Beagle.Tile {
 					p.StartInfo.Arguments = commandArgs;
 				try {
 					p.Start ();
-				} catch { }
+				} catch (Exception e) {
+					Console.WriteLine ("Unable to run {0}: {1}", command, e);
+				}
 				return;
 			}
 
@@ -267,38 +269,38 @@ namespace Beagle.Tile {
 			TileCanvasRenderContext ctx;
 			ctx = new TileCanvasRenderContext (this, 
 							   tile);
-			ctx.Write ("<html><style type=\"text/css\" media=\"screen\">");
 
+			// IMPORTANT!  The <meta> tag has to be in the first
+			// chunk written to the stream or else the encoding
+			// will be wrong!
+			ctx.Write ("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n");
+
+       			ctx.Write ("<style type=\"text/css\" media=\"screen\">\n");
 			RenderStyles (ctx);
-			
-			ctx.Write ("</style>");
+			ctx.Write ("</style>\n"); 
+
+			ctx.Write ("</head>\n");
 
 			if (tile != null) {
 				tile.Render (ctx);
 			}
+
 			ctx.Write ("</html>");
 		}
 		
 		/////////////////////////////////////////////////
 
-		StringBuilder source;
+		StringBuilder content;
 
 		public String Source {
-			get { return source.ToString (); }
+			get { return content.ToString (); }
+		}
+
+		public new void AppendData (string data)
+		{
+			content.Append (data);
 		}
 	
-		public new void AppendData(string data)
-		{
-			source.Append(data);
-			base.AppendData(data);
-		}
-
-		public new void OpenStream(string baseurl, string mimetype)
-		{
-			source = new StringBuilder ();
-			base.OpenStream (baseurl, mimetype);
-		}
-
 		/////////////////////////////////////////////////
 
 		private void DoRender ()
@@ -317,9 +319,10 @@ namespace Beagle.Tile {
 			string mime_type = "text/html";
 			if (Environment.GetEnvironmentVariable ("BEST_DEBUG_HTML") != null)
 			    mime_type = "text/plain";
-			OpenStream ("file:///", mime_type);
+
+			content = new StringBuilder ();
 			PaintTile (root);
-			CloseStream ();
+			RenderData (content.ToString (), "file:///", mime_type);
 
 			if (PostRenderEvent != null)
 				PostRenderEvent (this, new EventArgs ());
