@@ -29,6 +29,7 @@ using System.Diagnostics;
 using System.IO;
 
 using BU = Beagle.Util;
+using Mono.Posix;
 
 namespace Beagle.Tile {
 
@@ -47,18 +48,23 @@ namespace Beagle.Tile {
 			string str;
 			int n = Hit.DirectoryInfo.GetFileSystemInfos().Length;
 			if (n == 0)
-				str =  "Empty";
-			else if (n == 1)
-				str = "Contains 1 Item";
+				str = Catalog.GetString ("Empty");
 			else
-				str = "Contains " + n + " Items";
+				str = String.Format (Catalog.GetPluralString ("Contains {0} Item", "Contains {0} Items", n), n);
+
 			Template["Contents"] = str;
 		}
 
 		[TileAction]
 		public override void Open ()
 		{
-			OpenFromMime (Hit, "nautilus", true);
+			OpenFromMime (Hit, "nautilus", "--no-desktop", true);
 		} 
+
+                [TileAction]
+                public void Reveal ()
+                {
+                        OpenFolder (Path.GetDirectoryName (Hit.Uri.LocalPath));
+                }
 	}
 }
