@@ -52,6 +52,15 @@ namespace Beagle.Daemon {
 
 		//////////////////////////
 
+		private bool delete_content;
+
+		public bool DeleteContent {
+			get { return this.delete_content; }
+			set { this.delete_content = value; }
+		}
+
+		//////////////////////////
+
 		private   ArrayList supported_mime_types = new ArrayList ();
 		private   ArrayList supported_extensions = new ArrayList ();
 		
@@ -203,23 +212,57 @@ namespace Beagle.Daemon {
 
 		private bool last_was_structural_break = true;
 
+		// This two-arg AppendText() will give flexibility to
+		// filters to segregate hot-contents and
+		// normal-contents of a para and call this method with
+		// respective contents.  
+		//
+		// str : Holds both the normal-contents and hot contents.
+		// strHot: Holds only hot-contents.
+		//
+		// Ex:- suppose the actual-content is "one <b>two</b> three"
+		// str = "one two three"
+		// strHot = "two"
+		//
+		// NOTE: HotUp() or HotDown() has NO-EFFECT on this variant 
+		// of AppendText ()
+		
+		public void AppendText (string str, string strHot)
+		{
+			if (!IsFrozen && str != null && str != "") {
+				
+				// FIXME: Do we need to handle '\n' in any 
+				// other way?
+				int i = 0;
+				string line;
+				string[] lines = str.Split ('\n');
+				for (i = 0; i < lines.Length; i++) {
+					line = lines[i].Trim();
+					if (line.Length > 0) {
+						ReallyAppendText (line, null);
+						AppendStructuralBreak ();
+					}
+				}
+			}
+			ReallyAppendText (null, strHot);
+		}
+		
 		public void AppendText (string str)
 		{
 			//Logger.Log.Debug ("AppendText (\"{0}\")", str);
-			if (! IsFrozen && str != null && str != "") {
+			if (! IsFrozen && str != null && str != "")
+				AppendText (str, IsHot ? str : null);
+		}
 
-				// FIXME: We should be smarter about newlines
-				if (str.IndexOf ('\n') != -1)
-					str = str.Replace ("\n", " ");
+		// Does adding text to to text/hot pools respectively.
+		private void ReallyAppendText (string str, string strHot)
+		{
+			if (!IsFrozen && strHot != null && strHot != "")
+				hotPool.Add (strHot.Trim()+" ");
 
+			if (str != null) {
 				textPool.Add (str);
 
-				// For Hot pool, Add the "whitespace"
-				// while adding text to it. This way
-				// we can avoid extra spaces.
-				if (IsHot)
-					hotPool.Add (str.Trim()+" ");
-
 				int pool_size = 0;
 				foreach (string x in textPool)
 					pool_size += x.Length;
@@ -239,7 +282,6 @@ namespace Beagle.Daemon {
 				last_was_structural_break = false;
 			}
 		}
-
 		private bool NeedsWhiteSpace (ArrayList array)
 		{
 			if (array.Count == 0)
@@ -461,6 +503,15 @@ namespace Beagle.Daemon {
 			if (tempFile != null)
 				File.Delete (tempFile);
 
+			if (currentInfo != null && this.DeleteContent) {
+				try {
+					currentInfo.Delete ();
+				} catch (Exception e) {
+					Logger.Log.Debug ("Caught exception trying to delete {0} in filter '{1}'",
+							  currentInfo.FullName, Name);
+					Logger.Log.Debug (e);					
+				}
+			}
 		}
 
 		private string PullFromArray (ArrayList array)
