@@ -194,19 +194,17 @@ namespace Beagle.Daemon.LauncherQueryable {
 				string [] sline = line.Split ('=');
 				if (sline.Length != 2)
 					continue;
-				if (!sline[1].Equals (""))  {
-					// FIXME:  add other language support
-					if (sline[0].Equals ("Exec")
-					    || sline[0].Equals ("Icon")
-					    || sline[0].Equals ("Name")
-					    || sline[0].Equals ("Comment")) {
 
-						if (sline[0].Equals ("Name"))
-							have_name = true;
+				// FIXME: We shouldnt really search fields that are in other locales than the current should we?
 
-						StringBuilder property = new StringBuilder ("fixme:");
-						indexable.AddProperty (Beagle.Property.NewKeyword (property.Append(sline[0]).ToString (), sline[1]));
-					}
+				if (sline [0].Equals ("Icon") || sline [0].Equals ("Exec")) {
+					indexable.AddProperty (Beagle.Property.NewUnsearched ("fixme:" + sline[0], sline[1]));
+				} else if (sline [0].StartsWith ("Name")) {
+					if (sline [0] == "Name")
+						have_name = true;
+					indexable.AddProperty (Beagle.Property.NewKeyword ("fixme:" + sline[0], sline[1]));
+				} else if (sline[0].StartsWith ("Comment")) {
+					   indexable.AddProperty (Beagle.Property.NewKeyword ("fixme:" + sline[0], sline[1]));
 				}
 			}
 			reader.Close ();
@@ -219,4 +217,3 @@ namespace Beagle.Daemon.LauncherQueryable {
 		}
 	}
 }
-
